#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-3rw2JWyNbHh9HJ7bhzg8IT
key:                  dhall-1.42.3-3rw2JWyNbHh9HJ7bhzg8IT
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  f83fb134f7788220f36d5cb46968bf8a
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-3rw2JWyNbHh9HJ7bhzg8IT
depends:
    Diff-0.5-4ukX0gtsBAVAFqhODQB2Y aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz
    aeson-pretty-0.8.10-FzerwUFuCwVFAzZJsDIw6C
    ansi-terminal-1.1-IwAJp8dkX5QGaRL16wepJP
    atomic-write-0.2.1.1-5rInVIyutoJjBUpakWkiu base-4.18.2.1
    base16-bytestring-1.0.2.0-H68TCw35DEF67v5ehYoI5v
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-IN9jUwBK0bV3S6k2Bgrxup
    cborg-0.2.10.0-DD1TQXesB9AAufXsb9Ge1f
    cborg-json-0.2.6.0-C3o2jB98lnfBQ8etX6Kndc containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    cryptohash-sha256-0.11.102.1-I5gofwfPN9OASeVEwYIW4F
    data-fix-0.3.4-IKILDwyIYAZaVVQsn3cJp deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-LZeL4ajJq32m8Kl3SdCKH exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-1ddFr4nn90iGr2XTtCyFas
    hashable-1.4.7.0-DcMaISCS2qf3eQMEkeWh0S haskeline-0.8.2.1
    http-client-0.7.19-86q5uP36PXVA1VU7ir8jG7
    http-client-tls-0.3.6.4-Jmopvhh6XJdDm7pjT39Fiq
    http-types-0.12.4-27GAurifKVpxMGrjggVXj
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-FZeM2D0SwgQIqL3zAXHxUp
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK mtl-2.3.1
    network-uri-2.6.4.2-I9XioeQOOP5Ac2FpC6EX17
    optparse-applicative-0.18.1.0-ImROGgSnUkvGvLupUIrfSI
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-JIk3hawSvt32DSB6xvGgHt
    pretty-simple-4.1.4.0-Dtfor7ShpVH7zCbI4HwTPu
    prettyprinter-1.7.1-Du8XnOZ5nvL2FdTwmHe7nl
    prettyprinter-ansi-terminal-1.1.3-FvKgiYPaH1vDw8Azr6oy8n
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.0-HLdXvCiO3QbIUecoSvRoN5
    serialise-0.2.6.1-GXkUdzD1Hk0LUo5COVLLJ template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-BPm5iTPcoXCLy16Gbsknoa
    text-short-0.1.6-L2cG2DQjNHGdoBQsbeKGu
    th-lift-instances-0.1.20-7szcpncbDtlDeiMEd5dP0o time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-APR3nkxbuYFHt9P11k8C63
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN
    vector-0.13.2.0-AKpLem9JWa2IilUORfhwQi

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

